@@ -1464,7 +1464,11 @@ def default_replace_missing_url(row):
             return row
 
 
-def apply_parser_clean(row, forward_from: Literal['','clean','strip'] = '') -> str:
+def apply_parser_clean(
+    row, 
+    forward_from: Literal['','clean','strip'] = '',
+    padrao_json=True
+) -> str:
     import json
     from bs4 import BeautifulSoup
 
@@ -1475,23 +1479,32 @@ def apply_parser_clean(row, forward_from: Literal['','clean','strip'] = '') -> s
             html_clean = row
             forward_from_history = ['']
             if(forward_from in forward_from_history):
-                html = json.loads(row)[2]['url']
+                if padrao_json:
+                    html_clean = json.loads(row)[2]['url']
+                    example = ['<','>']
+                    example_replace = [' <','> ']
+                    for i, x in enumerate(example):
+                        html_clean = html_clean.replace(x,example_replace[i])
+                    soup = BeautifulSoup(html_clean, 'html.parser')
+                    html_clean = soup.get_text()
+                    
                 example = ['<','>']
                 example_replace = [' <','> ']
-                html_clean = html
                 for i, x in enumerate(example):
                     html_clean = html_clean.replace(x,example_replace[i])
-                soup = BeautifulSoup(html_clean, 'html.parser')
+                soup = BeautifulSoup(html_clean, 'lxml')
                 html_clean = soup.get_text()
 
-                sub_txts = ['5 8 8 17','5.8.8.17']
-                for sub in sub_txts:
-                    x = html_clean.find(sub)
-                    if(x!=-1):
-                        html_clean = html_clean[x+len(sub):]
+            sub_txts = ['5 8 8 17','5.8.8.17']
+            for sub in sub_txts:
+                x = html_clean.find(sub)
+                if(x!=-1):
+                    html_clean = html_clean[x+len(sub):]
+                        
             forward_from_history.append('clean')
             if(forward_from in forward_from_history):
                 html_clean = cleanString(html_clean)
+                
             forward_from_history.append('strip')
             if(forward_from in forward_from_history):                
                 html_clean = " ".join([
@@ -1500,7 +1513,8 @@ def apply_parser_clean(row, forward_from: Literal['','clean','strip'] = '') -> s
                     if (len(bigger_word) > 1)
                     if bigger_word.count(bigger_word[0]) != len(bigger_word)
                 ])
-                return(html_clean)
+            return (html_clean)
+        
         except KeyError as e:
             # print(e.with_traceback, e, row)
             return 'apply_parser_clean_KeyError'
@@ -1541,7 +1555,8 @@ def do_semantic_information_retrieval_gpu(
     embedder: SentenceTransformer,
     mvp: bool = False,
     print_results: bool = True,
-    sentences_1_col_name: str = 'keywords'
+    sentences_1_col_name: str = 'keywords',
+    sort_by_score: bool = True,
 ) -> None:
     """Consulta informação
 
@@ -1566,12 +1581,16 @@ def do_semantic_information_retrieval_gpu(
             }
         )
     if type(sentences1) == pd.DataFrame:
-        sentences1[sentences_1_col_name] = sentences1[sentences_1_col_name].apply(lambda x: apply_parser_clean(x, forward_from='clean'))
+        query = pd.DataFrame(
+            {
+                sentences_1_col_name : sentences1[sentences_1_col_name].apply(lambda x: apply_parser_clean(x, forward_from='clean'))
+            }
+        )
     else:
         raise TypeError('sentences1 must be a pd.DataFrame')
-    for i, _ in enumerate(sentences1):
+    for i, _ in enumerate(query):
         query_embedding = embedder.encode(
-            sentences1.iloc[i, 0], convert_to_tensor=True
+            query.iloc[i, 0], convert_to_tensor=True
         )
         # usar semantic_search para encontrar os k melhores scores
         top_results = util.semantic_search(
@@ -1582,7 +1601,7 @@ def do_semantic_information_retrieval_gpu(
             print("====================== \n")
             print(
                 "Consulta: \n\n",
-                sentences1.iloc[i, 0],
+                query.iloc[i, 0],
             )
             print("\n====================== \n")
 
@@ -1602,7 +1621,9 @@ def do_semantic_information_retrieval_gpu(
             # left_on='index',
             left_index=True,
             right_on='corpus_id'
-        ).sort_values(by='score', ascending=False).reset_index(drop=True)
+        )
+        if sort_by_score:
+            df_semantic_return = df_semantic_return.sort_values(by='score', ascending=False).reset_index(drop=True)
         # return df_semantic_return
         for resp_semantic in top_results:
             ## semantic search
@@ -1620,7 +1641,7 @@ def do_semantic_information_retrieval_gpu(
                 )
                 print("=======================\n")
         if mvp:
-            return df_semantic_return, sentences1[sentences_1_col_name]
+            return df_semantic_return, query[sentences_1_col_name]
         else:
             return df_semantic_return
         # break  #
